git: 2f35e7d9fa03 - main - kernel: partially revert e9efb1125a15, default inet mask

From: Mike Karels <karels_at_FreeBSD.org>
Date: Sun, 14 Nov 2021 20:13:35 UTC
The branch main has been updated by karels:

URL: https://cgit.FreeBSD.org/src/commit/?id=2f35e7d9fa03f27543f347cd6277af5bfc6a7e95

commit 2f35e7d9fa03f27543f347cd6277af5bfc6a7e95
Author:     Mike Karels <karels@FreeBSD.org>
AuthorDate: 2021-11-10 21:35:33 +0000
Commit:     Mike Karels <karels@FreeBSD.org>
CommitDate: 2021-11-14 20:12:25 +0000

    kernel: partially revert e9efb1125a15, default inet mask
    
    When no mask is supplied to the ioctl adding an Internet interface
    address, revert to using the historical class mask rather than a
    single default.  Similarly for the NFS bootp code.
    
    MFC after:      3 weeks
    Reviewed by:    melifaro glebius
    Differential Revision: https://reviews.freebsd.org/D32951
---
 sys/netinet/in.c     | 17 +++++++++++++----
 sys/nfs/bootp_subr.c | 13 ++++++++++---
 2 files changed, 23 insertions(+), 7 deletions(-)

diff --git a/sys/nfs/bootp_subr.c b/sys/nfs/bootp_subr.c
index a6dfbe0334f8..eedda7baa377 100644
--- a/sys/nfs/bootp_subr.c
+++ b/sys/nfs/bootp_subr.c
@@ -42,6 +42,8 @@
  *	$NetBSD: krpc_subr.c,v 1.10 1995/08/08 20:43:43 gwr Exp $
  */
 
+#define IN_HISTORICAL_NETS		/* include class masks */
+
 #include <sys/cdefs.h>
 __FBSDID("$FreeBSD$");
 
@@ -1486,11 +1488,16 @@ bootpc_decode_reply(struct nfsv3_diskless *nd, struct bootpc_ifcontext *ifctx,
 
 	if (ifctx->gotnetmask == 0) {
 		/*
-		 * If there is no netmask, use a default, but we really
-		 * need the right mask from the server.
+		 * If there is no netmask, use historical default,
+		 * but we really need the right mask from the server.
 		 */
 		printf("%s: no netmask received!\n", ifctx->ireq.ifr_name);
-		ifctx->netmask.sin_addr.s_addr = htonl(IN_NETMASK_DEFAULT);
+		if (IN_CLASSA(ntohl(ifctx->myaddr.sin_addr.s_addr)))
+			ifctx->netmask.sin_addr.s_addr = htonl(IN_CLASSA_NET);
+		else if (IN_CLASSB(ntohl(ifctx->myaddr.sin_addr.s_addr)))
+			ifctx->netmask.sin_addr.s_addr = htonl(IN_CLASSB_NET);
+		else
+			ifctx->netmask.sin_addr.s_addr = htonl(IN_CLASSC_NET);
 	}
 }
diff --git a/sys/netinet/in.c b/sys/netinet/in.c
index fccad3d9ede2..70fbe32c05ac 100644
--- a/sys/netinet/in.c
+++ b/sys/netinet/in.c
@@ -35,6 +35,8 @@
 #include <sys/cdefs.h>
 __FBSDID("$FreeBSD$");
 
+#define IN_HISTORICAL_NETS		/* include class masks */
+
 #include <sys/param.h>
 #include <sys/eventhandler.h>
 #include <sys/systm.h>
@@ -467,17 +469,24 @@ in_aifaddr_ioctl(u_long cmd, caddr_t data, struct ifnet *ifp, struct thread *td)
 		ia->ia_sockmask = *mask;
 		ia->ia_subnetmask = ntohl(ia->ia_sockmask.sin_addr.s_addr);
 	} else {
+		in_addr_t i = ntohl(addr->sin_addr.s_addr);
+
 		/*
 	 	 * If netmask isn't supplied, use default for now.
 		 * This is deprecated for interfaces other than loopback
 		 * or point-to-point; warn in other cases.  In the future
 		 * we should return an error rather than warning.
 	 	 */
 		if ((ifp->if_flags & (IFF_POINTOPOINT | IFF_LOOPBACK)) == 0)
-			printf("%s: set address: WARNING: network mask"
-			     " should be specified; using default mask\n",
+			printf("%s: set address: WARNING: network mask "
+			     "should be specified; using historical default\n",
 			     ifp->if_xname);
-		ia->ia_subnetmask = IN_NETMASK_DEFAULT;
+		if (IN_CLASSA(i))
+			ia->ia_subnetmask = IN_CLASSA_NET;
+		else if (IN_CLASSB(i))
+			ia->ia_subnetmask = IN_CLASSB_NET;
+		else
+			ia->ia_subnetmask = IN_CLASSC_NET;
 		ia->ia_sockmask.sin_addr.s_addr = htonl(ia->ia_subnetmask);
 	}
 	ia->ia_subnet = ntohl(addr->sin_addr.s_addr) & ia->ia_subnetmask;
@@ -467,17 +469,24 @@ in_aifaddr_ioctl(u_long cmd, caddr_t data, struct ifnet *ifp, struct thread *td)
 		/*
-	 	 * If netmask isn't supplied, use default for now.
+	 	 * If netmask isn't supplied, use historical default.
 		 * This is deprecated for interfaces other than loopback
 		 * or point-to-point; warn in other cases.  In the future